@@ -281,7 +281,7 @@ def get_username():
 
 
 def files_changed_between_commits(from_commit, to_commit):
-    p = subprocess.Popen(
+    p = subprocess.Popen(  # pylint: disable=consider-using-with
         ["git", "diff", from_commit, to_commit, "--name-only"], stdout=subprocess.PIPE
     )
     result = p.communicate()[0]
