@@ -76,3 +76,11 @@ class GithubHandler:
 
     def get_releases(self, repo):
         return self.get_repo(repo).get_releases()
+
+    def get_branches(self, repo):
+        return self.get_repo(repo).get_branches()
+
+    def get_raw_content(self, repo, ref):
+        repo = self.get_repo(repo)
+        content = repo.get_contents(".service.yml", ref)
+        return content.decoded_content
